<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: confirm.php 5550 2006-08-10 22:28:44Z toddy $
#
#  Copyright 2001 (c) Jaime Villate <villate@gnu.org>
#
# The Savane project is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# The Savane project is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with the Savane project; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

require "../include/pre.php";

$HTML->header(array('title'=>'Confirmation to leave project '. $group_name));
?>

<table width="100%" cellpadding="5" cellspacing="0" border="0">
<tr><td width="65%" valing="top">
<p>
Are you sure you want to be taken out from the list of developers
of project <?php echo $group_name; ?>?.
</p>
</td>
</tr>
<tr><td width="65%" valing="top">
<table cellpadding="5" cellspacing="5" border="0">
<tr><td>

<!-- Yes, remove user from project -->
<?php

echo '<form action="rmproject.php" method="get">';
echo '<input type="hidden" name="group_id" value="'.$group_id.'" />';
?>
<input type="submit" value="Yes" />
</form>
</td><td>

<!-- No, don't remove user from project -->
<form action="index.php" method="get">
<input type="submit" value="No!" />
</form>

</td></tr></table>
</td></tr></table>

<?php

 $HTML->footer(array()); 

?>

